<!-- Signature: poko class library version 0.0.2 (cls_form.php) -->
<?php

/**
* @class cls_form
*
* @brief Simply Output form tag class.
*
* <pre>
*  FORMϤΤδʰץåѡ饹
*
* ޤǤform, inputϤ뤿Υ饹Ǥꡢ
* ɤ¤٤뤫ǡϤɤϤΤϤΥ饹Ѥ¦ȽǤȤʤ롣
* 󥹥ȥ饯ƤۤȤɤȤ롣inputѤץѥƥ
* ϢȤƼꡢwhile(list-each)ʸǽϤ롣
*
*  selectʤɤϥץѥƥΤȡºݤ˥˥塼˻ȤĤ
* Ȥ롣
*  hiddenξ硢Ȥʤname, valueȤºݤΥǡΤߤǤ롣
*  ץѥƥ󤫤ƤΤǡߤ򥫥ޥʤäΤʤ
* "class" => "_css_style_class"ȤǤ⤷ƥ륷ȤȤȤ褤
* </pre>
* @author   Masahiko Sakamoto(sakamoto@c-hino.org)
* @version  $Id: cls_form.php,v 1.1.1.1 2004/05/23 12:31:42 m_sakamoto Exp $
*
* @internal
* Ǻ 2002/06/24
* ʹߤ礯礯ޥʡѹäƤ롣
*
*/
class cls_form {

	/**
	* @var		action
	* This indicates "action" option of \<form\> tag.
	* @see		_start_form()
	*/
	var $action = "";

	/**
	* @var		method
	* This indicates "method" option of \<form\> tag.
	* @see		_start_form()
	*/
	var $method = "post";

	/**
	* @var		target
	* This indicates "target" option of \<form\> tag.
	* @see		_start_form()
	*/
	var $target = "_self";

	/**
	* @var		enctype
	* This indicates "enctype" option of \<form\> tag.
	* @see		_start_form()
	*/
	var $enctype = "multipart/form-data";

	/**
	* @var		template_table
	* This indicates \<table\> tag option which may be used by other classes.
	* @internal	Out Of Use(for Upper Compatibility)
	*/
	var $template_table = "border";

	/**
	* @var		template_th
	* This indicate \<th\> tag option which may be used by other classes.
	* @internal	Out Of Use(for Upper Compatibility)
	*/
	var $template_th = "";

	/**
	* @var		template_tr
	* This indicates \<tr\> tag option which may be used by other classes.
	* @internal	Out Of Use(for Upper Compatibility)
	*/ 
	var $template_tr = "";

	/**
	* @var		template_td
	* This indicates \<td\> tag option which may be used by other classes.
	* @internal	Out Of Use(for Upper Compatibility)
	*/
	var $template_td = "";

	/**
	* @var		template_td_field
	* This indicates \<td\> tag option which handled as the \b name(field) of field.
	* @internal	Out Of Use(for Upper Compatibility)
	*/
	var $template_td_field = "";

	/**
	* @var		template_td_value
	* This indicates \<td\> tag option which handled as the \b value of field.
	* @internal	Out Of Use(for Upper Compatibility)
	*/
	var $template_td_value = "";

	/**
	* Print "form" tag and that's options.
	*
	* @see		_start_form()
	*/
	function start_form() {
		print $this->_start_form();
	} // end func start_form

	/**
	* Return "form" tag and that's options.
	*
	* @return	tag strings
	* @see		start_form(), start_form_trap()
	*/
	function _start_form() {
		$str = "<form action=\"$this->action\" method=\"$this->method\" target=\"$this->target\" enctype=\"$this->enctype\">\n";
		$this->start_form_trap();
		return $str;
	} // end func _start_form

	/**
	* Trapping Function for start_form() (other says "Hooking Function"?)
	* For Override Usage.
	*/
	function start_form_trap() {
	} // end func start_form_trap

	/**
	* Print "/form" tag
	*
	* @see		_end_form()
	*/
	function end_form() {
		print $this->_end_form();
	} // end func end_form

	/**
	* Return "/form" tag
	*
	* @return	tag strings
	* @see		end_form()
	*/
	function _end_form() {
		return "</form>\n";
	} // end func _end_form

	/**
	* Print Submit Button. This Only Wraps _submit_form().
	*
	* i.e. submit_form(array("value" => "ޤ", "class" => "_css_submit", "name" => "button1"));
	*
	* @param	array	array of input tag options.
	* @see		_submit_form()
	*/
	function submit_form($array) {
		print $this->_submit_form($array);
	} // end func submit_form

	/**
	* Return Submit Button form tag strings.
	*
	* @param	array	array of input tag options.
	* @return	tag strings.
	* @see		submit_form()
	*/
	function _submit_form($array) {
		$form = "<input type=submit ";
		while(list($key, $value) = each($array)) {
			$form .= "$key=\"$value\" ";
		}
		$form .= ">\n";
		return $form;
	} // end func _submit_form

	/**
	* Print Reset Button. This Only Wraps _reset_form().
	*
	* i.e. reset_form(array("value" => "ľ", "class" => "_css_reset"));
	*
	* @param	array	array of input tag options.
	* @see		_reset_form()
	*/
	function reset_form($array) {
		print $this->_reset_form($array);
	} // end func reset_form

	/**
	* Return Reset Button form tag strings.
	*
	* @param	array	array of input tag options.
	* @return	tag strings.
	* @see		reset_form()
	*/
	function _reset_form($array) {
		$form = "<input type=reset ";
		while(list($key, $value) = each($array)) {
			$form .= "$key=\"$value\" ";
		}
		$form .= ">\n";
		return $form;
	} // end func _reset_form

	/**
	* Print Text Input form. This Only Wraps _text_form().
	*
	* i.e. text_form(array("size" => "20", "value" => "̾ϤƤ",
	*	"maxlength" => "10", "name" => "_user_name",
	*	"autocomplete" => "on", "class" => "_css_text"));
	*
	* @param	array	array of input tag options.
	* @see		_text_form()
	*/
	function text_form($array) {
		print $this->_text_form($array);
	} // end func text_form

	/**
	* Return Text Input form tag strings.
	*
	* @param	array	array of input tag options.
	* @return	tag strings.
	* @see		text_form()
	*/
	function _text_form($array) {
		$form = "<input type=text ";
		while(list($key, $value) = each($array)) {
			$form .= "$key=\"$value\" ";
		}
		$form .= ">\n";
		return $form;
	} // end func _text_form


	/**
	* Print Password Input form. This Only Wraps _password_form().
	*
	* i.e. password_form(array("size" => "20", "value" => "*",
	*	"maxlength" => "10", "name" => "_user_pass",
	*	"autocomplete" => "on", "class" => "_css_pass"));
	*
	* @param	array	array of input tag options.
	* @see		_password_form()
	*/
	function password_form($array) {
		print $this->_password_form($array);
	} // end func password_form

	/**
	* Return Password Input form tag strings.
	*
	* @param	array	array of input tag options.
	* @return	tag strings.
	* @see		password_form()
	*/
	function _password_form($array) {
		$form = "<input type=password ";
		while(list($key, $value) = each($array)) {
			$form .= "$key=\"$value\" ";
		}
		$form .= ">\n";
		return $form;
	} // end func _password_form

	/**
	* Print Text Area (Multi Line) form. This Only Wraps _textarea_form().
	*
	* i.e. textarea_form(array("rows" => "10", "cols" => "20",
	*	"name" => "_memo", "wrap" => "hard" (//soft, off),
	*	"accesskey" => "T", "class" => "_css_memo"),
	*	"Ĺʸ󡢥ɽޤ");
	*
	* @param	array	array of textarea tag options.
	* @param	str	default text.
	* @see		_textarea_form()
	*/
	function textarea_form($array, $str = "") {
		print $this->_textarea_form($array, $str);
	} // end func textarea_form

	/**
	* Return Text Area (Multi Line) form tag strings.
	*
	* @param	array	array of textarea tag options.
	* @param	str	default text.
	* @return	tag strings.
	* @see		textarea_form()
	*/
	function _textarea_form($array, $str = "") {
		$form = "<textarea ";
		while(list($key, $value) = each($array)) {
			$form .= "$key=\"$value\" ";
		}
		$form .= ">\n$str\n</textarea>\n";
		return $form;
	} // end func _textarea_form

	/**
	* Print "max_file_size" hidden form. This Only Wraps _file_size_form().
	*
	* i.e. file_size_form(100000); //100kB
	*
	* @param	value	Uploadable max file size at byte.
	* @see		_file_size_form()
	*/
	function file_size_form($value) {
		print $this->_file_size_form($value);
	} // end func file_size_form

	/**
	* Return "max_file_size" hidden form tag strings.
	*
	* @param	value	Uploadable max file size at byte.
	* @return	tag strings.
	* @see		file_size_form()
	*/
	function _file_size_form($value) {
		$str = "<input type=hidden name=max_file_size value=$value>\n";
		return $str;
	} // end func _file_size_form

	/**
	* Print File upload form. This Only Wraps _file_form().
	*
	* i.e. file_form(array("size" => "100", "maxlength" => "80", "class" => "_css_file"));
	*
	* @param	array	array of input tag options.
	* @see		_file_form()
	*/
	function file_form($array) {
		print $this->_file_form($array);
	} // end func file_form

	/**
	* Return File upload form tag strings.
	*
	* @param	array	array of input tag options.
	* @return	tag strings.
	* @see		file_form()
	*/
	function _file_form($array) {
		$form = "<input type=file ";
		while(list($key, $value) = each($array)) {
			$form .= "$key=\"$value\" ";
		}
		$form .= ">\n";
		return $form;
	} // end func _file_form

	/**
	* Print Radio button form. This Only Wraps _radio_form().
	*
	* i.e. radio_form(array("name" => "_rd", "value" => "r1", "class" => "_css_radio"), "饸ܥ", "checked");
	*
	* @param	array	array of input tag options.
	* @param	str	radio button caption.
	* @param	checked	if specified not zero, default state is checked.
	* @see		_radio_form()
	*/
	function radio_form($array, $str, $checked="") {
		print $this->_radio_form($array, $str, $checked);
	} // end func radio_form

	/**
	* Return Radio button form tag strings.
	*
	* @param	array	array of input tag options.
	* @param	str	radio button caption.
	* @param	checked	if specified not zero, default state is checked.
	* @return	tag strings.
	* @see		radio_form()
	*/
	function _radio_form($array, $str, $checked="") {
		$form = "<input type=radio ";
		while(list($key, $value) = each($array)) {
			$form .= "$key=\"$value\" ";
		}
		$form .= "$checked>$str\n";
		return $form;
	} // end func _radio_form

	/**
	* Print Checkbox form. This Only Wraps _checkbox_form().
	*
	* i.e. checkbox_form(array("name" => "cb1[]", "value" => "cb1", "class" => "_css_cb"), "åܥå", "checked");
	*
	* @param	array	array of input tag options.
	* @param	str	caption of checkbox.
	* @param	checked	if specified not zero, default state is checked.
	* @see		_checkbox_form()
	*/
	function checkbox_form($array, $str, $checked="") {
		print $this->_checkbox_form($array, $str, $checked);
	} // end func checkbox_form

	/**
	* Return Checkbox form tag strings.
	*
	* @param	array	array of input tag options.
	* @param	str	caption of checkbox.
	* @param	checked	if specified not zero, default state is checked.
	* @return	tag strings.
	* @see		checkbox_form()
	*/
	function _checkbox_form($array, $str, $checked="") {
		$form = "<input type=checkbox ";
		while(list($key, $value) = each($array)) {
			$form .= "$key=\"$value\" ";
		}
		$form .= "$checked>$str\n";
		return $form;
	} // end func _checkbox_form

	/**
	* Print Select menu items. This Only Wraps _select_form().
	*
	* i.e. select_form(array("name" => "sel1" (//, "size" => "5"), "class" => "_css_select"),
	*	array("ǡ" => "dt1", "ǡ" => "dt2", "ǡ" => "dt3"),2);
	*
	* @param	array	array of select tag options.
	* @param	data	array of items which contains value and caption.
	* @param	index	index (which start from zero) of default selected item.
	* @see		_select_form()
	*/
	function select_form($array, $data, $index=0) {
		print $this->_select_form($array, $data, $index);
	} // end func select_form

	/**
	* Return Select menu items tag strings.
	*
	* @param	array	array of select tag options.
	* @param	data	array of items which contains value and caption.
	* @param	index	index (which start from zero) of default item.
	* @return	tag strings.
	* @see		select_form()
	*/
	function _select_form($array, $data, $index=0) {
		$form = "<select ";
		while(list($key, $value) = each($array)) {
			$form .= "$key=\"$value\" ";
		}
		$form .= ">\n";
		$i = 0;
		while(list($key, $value) = each($data)) {
			$selected = ($i == $index) ? "selected":"";
			$form .= "<option value=$value $selected>$key\n";
			$i++;
		}
		$form .= "</select>\n";
		return $form;
	} // end func _select_form

	/**
	* Print Hidden tag values. This Only Wraps _hidden_form().
	*
	* i.e. hidden_form(array("data1" => "ƿ̾˾", "data2" => "Ȥᤤ", "data3" => "ܤ"));
	*
	* @param	array	array of hidden values which contains value and variable name.
	* @see		_hidden_form()
	*/
	function hidden_form($array) {
		print $this->_hidden_form($array);
	} // end func hidden_form

	/**
	* Return Hidden tag values as strings.
	*
	* @param	array	array of hidden values which contains value and variable name.
	* @return	tag strings.
	* @see		hidden_form()
	*/
	function _hidden_form($array) {
		$str = "";
		while(list($key, $value) = each($array)) {
			$str .= "<input type=hidden name=\"$key\" value=\"$value\">\n";
		}
		return $str;
	} // end func _hidden_form
}
?>
